pub struct Frequency {
pub carrier: Carrier,
pub north: f64,
pub east: f64,
pub up: f64,
pub patterns: Vec<Pattern>,
}Expand description
Describes “frequency” data attached to a specific Antenna in the ATX record
Fields
carrier: CarrierCarrier, example: “L1”, “L2” for GPS, “E1”, “E5” for GAL…
north: f64Northern component of the mean antenna phase center
relative to the antenna reference point (ARP), in mm.
east: f64Eastern component of the mean antenna phase center
relative to the antenna reference point (ARP), in mm.
up: f64Z component of the mean antenna phase center relative
to the antenna reference point (ARP), in mm.
patterns: Vec<Pattern>Phase pattern, values in mm from antenna.zen1 to antenna.zen2
with increment antenna.dzen, can either be azimuth or non azimmuth dependent
Implementations
Sourceimpl Frequency
impl Frequency
pub fn with_carrier(&self, carrier: Carrier) -> Self
pub fn with_northern_eccentricity(&self, north: f64) -> Self
pub fn with_eastern_eccentricity(&self, east: f64) -> Self
pub fn with_upper_eccentricity(&self, up: f64) -> Self
pub fn add_pattern(&self, p: Pattern) -> Self