Helper

Struct Helper 

pub struct Helper {
Show 13 fields pub sv: SV, pub t_k: f64, pub u_k: f64, pub r_k: f64, pub i_k: f64, pub omega_k: f64, pub fd_u_k: f64, pub fd_r_k: f64, pub fd_i_k: f64, pub fd_omega_k: f64, pub dtr: f64, pub fd_dtr: f64, pub r_sv: (f64, f64, f64),
}
Available on crate feature nav only.
Helper helps calcualte satellite orbital state from Keplerian elements.

Fields

sv: SV

SV satellite identity

t_k: f64

The difference between the calculated time and the ephemeris reference time

u_k: f64

Ascending angle (corrected) in radians

r_k: f64

Radius(corrected) in radians

i_k: f64

Orbital inclination (corrected) in radians

omega_k: f64

Ascending node right ascension (in radians)

fd_u_k: f64

First Derivative of Ascending angle(corrected)

fd_r_k: f64

First Derivative of Radius(corrected)

fd_i_k: f64

First Derivative of Orbital inclination(corrected)

fd_omega_k: f64

First Derivative of Ascending node right ascension

dtr: f64

Relativistic Effect Correction

fd_dtr: f64

First Derivative of Relativistic Effect Correction

r_sv: (f64, f64, f64)

r_sv in meters ECEF

Implementations

Source

impl Helper

pub fn ecef_position(&self) -> Vector3

Calculate ecef position [km].

pub fn ecef_velocity(&self) -> Vector3

Returns ECEF velocity Vector3 in km/s.

pub fn ecef_pv(&self) -> (Vector3, Vector3)

Returns ECEF (position, velocity) Vector3 in (km, km/s).

pub fn beidou_geo_ecef_position(&self) -> Vector3

Returns ECEF position Vector3 in km, for BeiDou GEO specifically

pub fn beidou_geo_ecef_velocity(&self) -> Vector3

Returns ECEF velocity Vector3 in km/s, for BeiDou GEO specifically

pub fn beidou_geo_ecef_pv(&self) -> (Vector3, Vector3)

Returns ECEF (position, velocity) Vector3s in (km, km/s), for BeiDou GEO specifically.

pub fn position(&self) -> Option<Vector3>

Returns ECEF position Vector3 in km.

pub fn position_velocity(&self) -> Option<(Vector3, Vector3)>

Returns (position, velocity) Vector3 duplet, in (km, km/s).