pub struct Helper {}nav only.Expand description
Helper helps calcualte satellite orbital state from Keplerian elements.
Fields
sv: SVSV satellite identity
t_k: f64The difference between the calculated time and the ephemeris reference time
u_k: f64Ascending angle (corrected) in radians
r_k: f64Radius(corrected) in radians
i_k: f64Orbital inclination (corrected) in radians
omega_k: f64Ascending node right ascension (in radians)
fd_u_k: f64First Derivative of Ascending angle(corrected)
fd_r_k: f64First Derivative of Radius(corrected)
fd_i_k: f64First Derivative of Orbital inclination(corrected)
fd_omega_k: f64First Derivative of Ascending node right ascension
dtr: f64Relativistic Effect Correction
fd_dtr: f64First Derivative of Relativistic Effect Correction
r_sv: (f64, f64, f64)r_sv in meters ECEF
Implementations
Sourceimpl Helper
impl Helper
Sourcepub fn ecef_position(&self) -> Vector3
pub fn ecef_position(&self) -> Vector3
Calculate ecef position [km].
Sourcepub fn ecef_velocity(&self) -> Vector3
pub fn ecef_velocity(&self) -> Vector3
Returns ECEF velocity Vector3 in km/s.
Sourcepub fn ecef_pv(&self) -> (Vector3, Vector3)
pub fn ecef_pv(&self) -> (Vector3, Vector3)
Returns ECEF (position, velocity) Vector3 in (km, km/s).
Sourcepub fn beidou_geo_ecef_position(&self) -> Vector3
pub fn beidou_geo_ecef_position(&self) -> Vector3
Returns ECEF position Vector3 in km, for BeiDou GEO specifically
Sourcepub fn beidou_geo_ecef_velocity(&self) -> Vector3
pub fn beidou_geo_ecef_velocity(&self) -> Vector3
Returns ECEF velocity Vector3 in km/s, for BeiDou GEO specifically
Sourcepub fn beidou_geo_ecef_pv(&self) -> (Vector3, Vector3)
pub fn beidou_geo_ecef_pv(&self) -> (Vector3, Vector3)
Returns ECEF (position, velocity) Vector3s in (km, km/s), for BeiDou GEO specifically.