pub struct ProductionAttributes {
pub name: String,
pub year: u32,
pub doy: u32,
pub v3_details: Option<DetailedProductionAttributes>,
pub region: Option<char>,
}Expand description
File production attributes. Used when generating RINEX data that follows standard naming conventions, or attached to data parsed from such files.
Fields
name: StringName serves several roles which are type dependent.
- Non detailed OBS RINEX: this is usually the station name which can be named after a geodetic marker
- Non detailed NAV RINEX: station name
- CLK RINEX: name of the local clock
- IONEX: agency
year: u32Year of production
doy: u32Production Day of Year (DOY)
v3_details: Option<DetailedProductionAttributes>Detailed production attributes that only apply to modern Navigation or Observations (either Meteo or Observation) RINEx.
region: Option<char>Optional Regional code present in IONEX file names. ‘G’ means Global (World wide) TEC map(s).